@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2005, The HSQL Development Group
+/* Copyright (c) 2001-2008, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -63,6 +63,8 @@ import org.hsqldb.resources.BundleHandler;
 // fredt@users 20040320 - 1.7.2 - review and correction
 // fredt@users 20050225 - 1.8.0 - minor corrections
 // fredt@users 20051231 - 1.8.1 - support for remote opening of databases
+// fredt@users 20080531 - 1.8.1 - removed synchronized from print methods
+// unnecessary and could cause deadlock
 
 /**
  * The HSQLDB HSQL protocol network database server. <p>
@@ -287,8 +289,7 @@ public class Server implements HsqlSocketRequestHandler {
 
             super(name);
 
-            setName(name + '@'
-                    + Integer.toString(Server.this.hashCode(), 16));
+            setName(name + '@' + Integer.toString(Server.this.hashCode(), 16));
         }
 
         /**
@@ -332,20 +333,24 @@ public class Server implements HsqlSocketRequestHandler {
      */
     public static void main(String[] args) {
 
-        String propsPath = FileUtil.canonicalOrAbsolutePath("server");
+        String propsPath =
+            FileUtil.getDefaultInstance().canonicalOrAbsolutePath("server");
         HsqlProperties fileProps =
             ServerConfiguration.getPropertiesFromFile(propsPath);
-        HsqlProperties props = fileProps == null ? new HsqlProperties()
-                                                 : fileProps;
+        HsqlProperties props       = fileProps == null ? new HsqlProperties()
+                                                       : fileProps;
         HsqlProperties stringProps = null;
+
         try {
             stringProps = HsqlProperties.argArrayToProps(args,
                     ServerConstants.SC_KEY_PREFIX);
         } catch (ArrayIndexOutOfBoundsException aioob) {
+
             // I'd like to exit with 0 here, but it's possible that user
             // has called main() programmatically and does not want us to
             // exit.
             printHelp("server.help");
+
             return;
         }
 
@@ -548,8 +553,8 @@ public class Server implements HsqlSocketRequestHandler {
     public String getDatabasePath(int index, boolean asconfigured) {
 
         if (asconfigured) {
-            return serverProperties.getProperty(
-                ServerConstants.SC_KEY_DATABASE + "." + index);
+            return serverProperties.getProperty(ServerConstants.SC_KEY_DATABASE
+                                                + "." + index);
         } else if (getState() == ServerConstants.SERVER_STATE_ONLINE) {
             return (dbPath == null || index < 0 || index >= dbPath.length)
                    ? null
@@ -616,10 +621,8 @@ public class Server implements HsqlSocketRequestHandler {
      *  description="At which ServerSocket listens for connections"
      */
     public int getPort() {
-
-        return serverProperties.getIntegerProperty(
-            ServerConstants.SC_KEY_PORT,
-            ServerConfiguration.getDefaultPort(serverProtocol, isTls()));
+        return serverProperties.getIntegerProperty(ServerConstants.SC_KEY_PORT,
+                ServerConfiguration.getDefaultPort(serverProtocol, isTls()));
     }
 
     /**
@@ -711,7 +714,7 @@ public class Server implements HsqlSocketRequestHandler {
      *  access="read-only"
      *  description="1:ONLINE 4:OPENING 8:CLOSING, 16:SHUTDOWN"
      */
-    public synchronized int getState() {
+    public int getState() {
         return serverState;
     }
 
@@ -921,7 +924,7 @@ public class Server implements HsqlSocketRequestHandler {
             throw new RuntimeException();
         }
 
-        path = FileUtil.canonicalOrAbsolutePath(path);
+        path = FileUtil.getDefaultInstance().canonicalOrAbsolutePath(path);
 
         HsqlProperties p = ServerConfiguration.getPropertiesFromFile(path);
 
@@ -1150,8 +1153,8 @@ public class Server implements HsqlSocketRequestHandler {
     public void setRestartOnShutdown(boolean restart) {
 
         printWithThread("setRestartOnShutdown(" + restart + ")");
-        serverProperties.setProperty(
-            ServerConstants.SC_KEY_AUTORESTART_SERVER, restart);
+        serverProperties.setProperty(ServerConstants.SC_KEY_AUTORESTART_SERVER,
+                                     restart);
     }
 
     /**
@@ -1373,6 +1376,10 @@ public class Server implements HsqlSocketRequestHandler {
      * @param action a code indicating what has happend
      */
     final void notify(int action, int id) {
+        notifyImpl(action, id);
+    }
+
+    protected void notifyImpl(int action, int id) {
 
         printWithThread("notifiy(" + action + "," + id + ") entered");
 
@@ -1439,7 +1446,7 @@ public class Server implements HsqlSocketRequestHandler {
      *
      * @param msg The message to print
      */
-    protected synchronized void print(String msg) {
+    protected void print(String msg) {
 
         PrintWriter writer = logWriter;
 
@@ -1484,7 +1491,7 @@ public class Server implements HsqlSocketRequestHandler {
      *
      * @param t the Throwable whose stack trace is to be printed
      */
-    protected synchronized void printStackTrace(Throwable t) {
+    protected void printStackTrace(Throwable t) {
 
         if (errWriter != null) {
             t.printStackTrace(errWriter);
@@ -1524,7 +1531,7 @@ public class Server implements HsqlSocketRequestHandler {
      *
      * @param msg the message to print
      */
-    protected synchronized void printError(String msg) {
+    protected void printError(String msg) {
 
         PrintWriter writer = errWriter;
 
@@ -1766,8 +1773,7 @@ public class Server implements HsqlSocketRequestHandler {
         HsqlProperties newprops = DatabaseURL.parseURL(filepath, false);
 
         if (newprops == null) {
-            RuntimeException e =
-                new RuntimeException("invalid database path");
+            RuntimeException e = new RuntimeException("invalid database path");
 
             printError("invalid database path");
             setServerError(e);
@@ -1779,8 +1785,7 @@ public class Server implements HsqlSocketRequestHandler {
         String type = newprops.getProperty("connection_type");
 
         try {
-            int dbid = DatabaseManager.getDatabase(type, path, this,
-                                                   newprops);
+            int dbid = DatabaseManager.getDatabase(type, path, this, newprops);
 
             dbID[i]    = dbid;
             dbAlias[i] = alias;
@@ -2030,8 +2035,7 @@ public class Server implements HsqlSocketRequestHandler {
     /** Prints a timestamped message indicating that this server is online */
     private void printServerOnlineMessage() {
 
-        String s = getProductName() + " " + getProductVersion()
-                   + " is online";
+        String s = getProductName() + " " + getProductVersion() + " is online";
 
         printWithTimestamp(s);
         printResource("online.help");
@@ -2282,6 +2286,6 @@ public class Server implements HsqlSocketRequestHandler {
      * @param key for message
      */
     protected static void printHelp(String key) {
-        System.out.println(BundleHandler.getString(serverBundleHandle, key));
+        System.out.print(BundleHandler.getString(serverBundleHandle, key));
     }
 }
