@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2005, The HSQL Development Group
+/* Copyright (c) 2001-2008, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -112,7 +112,7 @@ public class Token {
     static final String T_CURRENT_ROLE                 = "CURRENT_ROLE";           //reserved
     static final String T_CURRENT_TIME                 = "CURRENT_TIME";           //reserved
     static final String T_CURRENT_TIMESTAMP            = "CURRENT_TIMESTAMP";      //reserved
-    static final String T_CURRENT_TRANS_TROUP_FOR_TYPE =
+    static final String T_CURRENT_TRANS_GROUP_FOR_TYPE =
         "CURRENT_TRANSFORM_GROUP_FOR_TYPE";                                        //reserved
     static final String        T_CURRENT_USER    = "CURRENT_USER";                 //reserved
     static final String        T_CURSOR          = "CURSOR";                       //reserved
@@ -341,6 +341,7 @@ public class Token {
     static final String        T_EVERY          = "EVERY";
     static final String        T_EXPLAIN        = "EXPLAIN";
     static final String        T_EXTRACT        = "EXTRACT";
+    static final String        T_FILES          = "FILES";
     static final String        T_GENERATED      = "GENERATED";
     static final String        T_IFNULL         = "IFNULL";
     static final String        T_IGNORECASE     = "IGNORECASE";
@@ -656,46 +657,49 @@ public class Token {
     static final int        CACHED                = 302;
     static final int        CHECKPOINT            = 303;
     static final int        EXPLAIN               = 304;
-    static final int        IGNORECASE            = 305;
-    static final int        INDEX                 = 306;
-    static final int        LOGSIZE               = 307;
-    static final int        MATCHED               = 308;
-    static final int        MAXROWS               = 309;
-    static final int        MEMORY                = 310;
-    static final int        MINUS                 = 311;
-    static final int        NEXT                  = 312;
-    static final int        OPENBRACKET           = 313;
-    static final int        PASSWORD              = 314;
-    static final int        PLAN                  = 315;
-    static final int        PROPERTY              = 316;
-    static final int        READONLY              = 317;
-    static final int        REFERENTIAL_INTEGRITY = 318;
-    static final int        RENAME                = 319;
-    static final int        RESTART               = 320;
-    static final int        SCRIPT                = 321;
-    static final int        SCRIPTFORMAT          = 322;
-    static final int        SEMICOLON             = 323;
-    static final int        SEQUENCE              = 324;
-    static final int        SHUTDOWN              = 325;
-    static final int        SOURCE                = 326;
-    static final int        TEMP                  = 327;
-    static final int        TEXT                  = 328;
-    static final int        VIEW                  = 329;
-    static final int        WRITE_DELAY           = 330;
+    static final int        FILES                 = 305;
+    static final int        IGNORECASE            = 306;
+    static final int        INDEX                 = 307;
+    static final int        LOGSIZE               = 308;
+    static final int        MATCHED               = 309;
+    static final int        MAXROWS               = 310;
+    static final int        MEMORY                = 311;
+    static final int        MINUS                 = 312;
+    static final int        NEXT                  = 313;
+    static final int        OPENBRACKET           = 314;
+    static final int        PASSWORD              = 315;
+    static final int        PLAN                  = 316;
+    static final int        PROPERTY              = 317;
+    static final int        READONLY              = 318;
+    static final int        REFERENTIAL_INTEGRITY = 319;
+    static final int        RENAME                = 320;
+    static final int        RESTART               = 321;
+    static final int        SCRIPT                = 322;
+    static final int        SCRIPTFORMAT          = 323;
+    static final int        SEMICOLON             = 324;
+    static final int        SEQUENCE              = 325;
+    static final int        SHUTDOWN              = 326;
+    static final int        SOURCE                = 327;
+    static final int        TEMP                  = 328;
+    static final int        TEXT                  = 329;
+    static final int        VIEW                  = 330;
+    static final int        WRITE_DELAY           = 331;
 
     // added stuff
-    static final int VAR_POP     = 330;
-    static final int VAR_SAMP    = 331;
-    static final int STDDEV_POP  = 332;
-    static final int STDDEV_SAMP = 333;
-    static final int DEFRAG      = 334;
-    static final int INCREMENT   = 335;
-    static final int TOCHAR      = 336;
-    static final int DATABASE    = 337;
-    static final int SCHEMA      = 338;
-    static final int ROLE        = 339;
+    static final int VAR_POP     = 340;
+    static final int VAR_SAMP    = 341;
+    static final int STDDEV_POP  = 342;
+    static final int STDDEV_SAMP = 343;
+    static final int DEFRAG      = 344;
+    static final int INCREMENT   = 345;
+    static final int TOCHAR      = 346;
+    static final int DATABASE    = 347;
+    static final int SCHEMA      = 348;
+    static final int ROLE        = 349;
     static final int DOW         = 340;
     static final int INITIAL     = 341;
+    static final int BACKUP      = 342;
+    static final int COLLATION   = 343;
 
     //
     static {
@@ -712,16 +716,18 @@ public class Token {
 
         IntValueHashMap commandSet;
 
-        commandSet = new IntValueHashMap(67);
+        commandSet = new IntValueHashMap(73);
 
         commandSet.put(T_ADD, ADD);
         commandSet.put(T_ALIAS, ALIAS);
         commandSet.put(T_ALTER, ALTER);
         commandSet.put(T_AUTOCOMMIT, AUTOCOMMIT);
+        commandSet.put(T_BACKUP, BACKUP);
         commandSet.put(T_CACHED, CACHED);
         commandSet.put(T_CALL, CALL);
         commandSet.put(T_CHECK, CHECK);
         commandSet.put(T_CHECKPOINT, CHECKPOINT);
+        commandSet.put(T_COLLATION, COLLATION);
         commandSet.put(T_COLUMN, COLUMN);
         commandSet.put(T_COMMIT, COMMIT);
         commandSet.put(T_CONNECT, CONNECT);
@@ -734,6 +740,7 @@ public class Token {
         commandSet.put(T_DROP, DROP);
         commandSet.put(T_EXCEPT, EXCEPT);
         commandSet.put(T_EXPLAIN, EXPLAIN);
+        commandSet.put(T_FILES, FILES);
         commandSet.put(T_FOREIGN, FOREIGN);
         commandSet.put(T_GRANT, GRANT);
         commandSet.put(T_IGNORECASE, IGNORECASE);
