@@ -1,4 +1,40 @@
-/* Copyright (c) 1995-2000, The Hypersonic SQL Group.
+/*
+ * For work developed by the HSQL Development Group:
+ *
+ * Copyright (c) 2001-2010, The HSQL Development Group
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ * Redistributions of source code must retain the above copyright notice, this
+ * list of conditions and the following disclaimer.
+ *
+ * Redistributions in binary form must reproduce the above copyright notice,
+ * this list of conditions and the following disclaimer in the documentation
+ * and/or other materials provided with the distribution.
+ *
+ * Neither the name of the HSQL Development Group nor the names of its
+ * contributors may be used to endorse or promote products derived from this
+ * software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
+ * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ *
+ *
+ * For work originally developed by the Hypersonic SQL Group:
+ *
+ * Copyright (c) 1995-2000, The Hypersonic SQL Group.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,40 +63,8 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * This software consists of voluntary contributions made by many individuals 
+ * This software consists of voluntary contributions made by many individuals
  * on behalf of the Hypersonic SQL Group.
- *
- *
- * For work added by the HSQL Development Group:
- *
- * Copyright (c) 2001-2005, The HSQL Development Group
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * Redistributions of source code must retain the above copyright notice, this
- * list of conditions and the following disclaimer.
- *
- * Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * Neither the name of the HSQL Development Group nor the names of its
- * contributors may be used to endorse or promote products derived from this
- * software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
- * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
- * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 
@@ -70,6 +74,7 @@ import java.io.File;
 import java.io.IOException;
 
 import org.hsqldb.Database;
+import org.hsqldb.DatabaseURL;
 import org.hsqldb.HsqlException;
 import org.hsqldb.NumberSequence;
 import org.hsqldb.Session;
@@ -138,6 +143,7 @@ public class Log {
     private int                    writeDelay;
     private int                    scriptFormat;
     private DataFileCache          cache;
+    private boolean                incBackup;
 
     Log(Database db) throws HsqlException {
 
@@ -153,10 +159,12 @@ public class Log {
         int logMegas = properties.getIntegerProperty(
             HsqlDatabaseProperties.hsqldb_log_size, 0);
 
-        maxLogSize = logMegas * 1024 * 1024;
+        maxLogSize = logMegas * 1024L * 1024;
         scriptFormat = properties.getIntegerProperty(
             HsqlDatabaseProperties.hsqldb_script_format,
             ScriptWriterBase.SCRIPT_TEXT_170);
+        incBackup = properties.isPropertyTrue(
+            HsqlDatabaseProperties.hsqldb_inc_backup);
         writeDelay     = properties.getDefaultWriteDelay();
         filesReadOnly  = database.isFilesReadOnly();
         scriptFileName = fileName + ".script";
@@ -208,6 +216,7 @@ public class Log {
                 }
 
             // continue as non-modified files
+            // fall through
             case HsqlDatabaseProperties.FILES_NOT_MODIFIED :
 
                 /**
@@ -319,6 +328,12 @@ public class Log {
 
     void backupData() throws IOException {
 
+        if (incBackup) {
+            fa.removeElement(fileName + ".backup");
+
+            return;
+        }
+
         if (fa.isStreamElement(fileName + ".data")) {
             ZipUnzipFile.compressFile(fileName + ".data",
                                       fileName + ".backup.new",
@@ -441,7 +456,7 @@ public class Log {
 
         long megas = properties.getIntegerProperty(
             HsqlDatabaseProperties.hsqldb_defrag_limit, 200);
-        long defraglimit = megas * 1024 * 1024;
+        long defraglimit = megas * 1024L * 1024;
         long lostSize    = cache.freeBlocks.getLostBlocksSize();
 
         return lostSize > defraglimit;
@@ -474,7 +489,7 @@ public class Log {
     }
 
     int getLogSize() {
-        return (int) (maxLogSize / (1024 * 11024));
+        return (int) (maxLogSize / (1024 * 1024));
     }
 
     void setLogSize(int megas) {
@@ -482,7 +497,7 @@ public class Log {
         properties.setProperty(HsqlDatabaseProperties.hsqldb_log_size,
                                String.valueOf(megas));
 
-        maxLogSize = megas * 1024 * 1024;
+        maxLogSize = megas * 1024L * 1024;
     }
 
     int getScriptType() {
@@ -495,10 +510,12 @@ public class Log {
      */
     void setScriptType(int type) throws HsqlException {
 
+        // OOo related code
         if (database.isStoredFileAccess()) {
             return;
         }
 
+        // end OOo
         boolean needsCheckpoint = scriptFormat != type;
 
         scriptFormat = type;
@@ -518,16 +535,48 @@ public class Log {
         return writeDelay;
     }
 
+    /**
+     * Write delay 0 means sync on each commit. Values larger than 0 and less
+     * than 10 ms are treated as 10 ms.
+     */
     void setWriteDelay(int delay) {
 
+        if (delay > 0 && delay < 10) {
+            delay = 10;
+        }
+
         writeDelay = delay;
 
         if (dbLogWriter != null) {
-            synchLog();
+            dbLogWriter.forceSync();
+            dbLogWriter.stop();
             dbLogWriter.setWriteDelay(delay);
+            dbLogWriter.start();
         }
     }
 
+    public void setIncrementalBackup(boolean val) throws HsqlException {
+
+        if (incBackup == val) {
+            return;
+        }
+
+        incBackup = val;
+
+        database.getProperties().setProperty(
+            HsqlDatabaseProperties.hsqldb_inc_backup, String.valueOf(val));
+        database.getProperties().save();
+
+        if (cache != null) {
+
+            // need to set file modified to force a backup if necessary
+            cache.incBackup    = true;
+            cache.fileModified = true;
+        }
+
+        database.logger.needsCheckpoint = true;
+    }
+
     /**
      * Various writeXXX() methods are used for logging statements.
      */
@@ -668,8 +717,7 @@ public class Log {
                                                        scriptFileName,
                                                        scriptFormat);
 
-                scr.readAll(database.sessionManager.getSysSession(null,
-                        true));
+                scr.readAll(database.sessionManager.getSysSession(null, true));
                 scr.close();
             }
         } catch (Throwable e) {
@@ -702,8 +750,14 @@ public class Log {
      */
     private void processDataFile() throws HsqlException {
 
-        if (cache == null || filesReadOnly || database.isStoredFileAccess()
-                ||!fa.isStreamElement(logFileName)) {
+        // OOo related code
+        if (database.isStoredFileAccess()) {
+            return;
+        }
+
+        // OOo end
+        if (cache == null || filesReadOnly
+                || !fa.isStreamElement(logFileName)) {
             return;
         }
 
@@ -732,6 +786,12 @@ public class Log {
      */
     private void restoreBackup() throws HsqlException {
 
+        if (incBackup) {
+            restoreBackupIncremental();
+
+            return;
+        }
+
         // in case data file cannot be deleted, reset it
         DataFileCache.deleteOrResetFreePos(database, fileName + ".data");
 
@@ -747,6 +807,36 @@ public class Log {
         }
     }
 
+    /**
+     * Restores in from an incremental backup
+     */
+    private void restoreBackupIncremental() throws HsqlException {
+
+        try {
+            if (fa.isStreamElement(fileName + ".backup")) {
+                RAShadowFile.restoreFile(fileName + ".backup",
+                                         fileName + ".data");
+            } else {
+/*
+                // this is to ensure file has been written fully but it is not necessary
+                // as semantics dictate that if a backup does not exist, the file
+                // was never changed or was fully written to
+                if (FileUtil.exists(cacheFileName)) {
+                    int flags = DataFileCache.getFlags(cacheFileName);
+
+                    if (!BitMap.isSet(flags, DataFileCache.FLAG_ISSAVED)) {
+                        FileUtil.delete(cacheFileName);
+                    }
+                }
+*/
+            }
+
+            deleteBackup();
+        } catch (IOException e) {
+            throw Trace.error(Trace.FILE_IO_ERROR, fileName + ".backup");
+        }
+    }
+
 // fredt@users 20020221 - patch 513005 by sqlbob@users (RMP) - text tables
     private HashMap textCacheList = new HashMap();
 
@@ -756,7 +846,9 @@ public class Log {
 
         closeTextCache(table);
 
-        if (!properties.isPropertyTrue("textdb.allow_full_path")) {
+        if (database.getType() != DatabaseURL.S_RES
+                && !properties.isPropertyTrue(
+                    HsqlDatabaseProperties.textdb_allow_full_path)) {
             if (source.indexOf("..") != -1) {
                 throw (Trace.error(Trace.ACCESS_IS_DENIED, source));
             }
