@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2005, The HSQL Development Group
+/* Copyright (c) 2001-2008, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,8 @@ package org.hsqldb.persist;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 
+import org.hsqldb.Database;
+import org.hsqldb.DatabaseURL;
 import org.hsqldb.HsqlException;
 import org.hsqldb.Table;
 import org.hsqldb.Trace;
@@ -46,7 +48,6 @@ import org.hsqldb.rowio.RowOutputText;
 import org.hsqldb.rowio.RowOutputTextQuoted;
 import org.hsqldb.scriptio.ScriptWriterText;
 import org.hsqldb.store.ObjectCacheHashMap;
-import org.hsqldb.Database;
 
 // Ito Kazumitsu 20030328 - patch 1.7.2 - character encoding support
 // Dimitri Maziuk - patch for NL in string support
@@ -60,8 +61,8 @@ import org.hsqldb.Database;
  * compatible pair of org.hsqldb.rowio input/output class instances.
  *
  *
- * @author sqlbob@users (RMP)
- * @version 1.8.0
+ * @author Bob Preston (sqlbob@users dot sourceforge.net)
+ * @version 1.8.1
  * @since 1.7.0
  */
 public class TextCache extends DataFileCache {
@@ -300,8 +301,12 @@ public class TextCache extends DataFileCache {
         fileFreePosition = 0;
 
         try {
+            int type = database.getType() == DatabaseURL.S_RES
+                       ? ScaledRAFile.DATA_FILE_JAR
+                       : ScaledRAFile.DATA_FILE_RAF;
+
             dataFile = ScaledRAFile.newScaledRAFile(database, fileName,
-                    readonly, ScaledRAFile.DATA_FILE_RAF, null, null);
+                    readonly, type, null, null);
             fileFreePosition = dataFile.length();
 
             if (fileFreePosition > Integer.MAX_VALUE) {
@@ -344,8 +349,8 @@ public class TextCache extends DataFileCache {
 
             dataFile = null;
 
-            if (empty &&!cacheReadonly) {
-                FileUtil.delete(fileName);
+            if (empty && !cacheReadonly) {
+                FileUtil.getDefaultInstance().delete(fileName);
             }
         } catch (Exception e) {
             throw Trace.error(Trace.FILE_IO_ERROR,
@@ -373,7 +378,7 @@ public class TextCache extends DataFileCache {
                     dataFile = null;
                 }
 
-                FileUtil.delete(fileName);
+                FileUtil.getDefaultInstance().delete(fileName);
             }
         } catch (Exception e) {
             throw Trace.error(Trace.FILE_IO_ERROR,
@@ -388,8 +393,7 @@ public class TextCache extends DataFileCache {
      *
      */
     public synchronized void remove(int pos,
-                                    PersistentStore store)
-                                    throws IOException {
+                                    PersistentStore store) throws IOException {
 
         CachedObject row = (CachedObject) uncommittedCache.remove(pos);
 
@@ -540,9 +544,8 @@ public class TextCache extends DataFileCache {
                     complete = true;
 
                     if (!cacheReadonly) {
-                        dataFile.write(
-                            ScriptWriterText.BYTES_LINE_SEP, 0,
-                            ScriptWriterText.BYTES_LINE_SEP.length);
+                        dataFile.write(ScriptWriterText.BYTES_LINE_SEP, 0,
+                                       ScriptWriterText.BYTES_LINE_SEP.length);
                     }
 
                     break;
@@ -782,6 +785,9 @@ public class TextCache extends DataFileCache {
         return ((RowInputText) rowIn).getLineNumber();
     }
 
+    protected void copyShadow(CachedObject[] rows, int offset,
+                              int count) throws IOException {}
+
     protected void setFileModified() throws IOException {
         fileModified = true;
     }
