@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2005, The HSQL Development Group
+/* Copyright (c) 2001-2008, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,23 +46,33 @@ public class AllTests extends TestCase {
         TestSuite suite = new TestSuite();
 
         suite.addTestSuite(org.hsqldb.test.TestBatchExecution.class);
+        suite.addTestSuite(org.hsqldb.test.TestBug1191815.class);//
         suite.addTestSuite(org.hsqldb.test.TestBug778213.class);
         suite.addTestSuite(org.hsqldb.test.TestBug785429.class);
         suite.addTestSuite(org.hsqldb.test.TestBug808460.class);
+        suite.addTestSuite(org.hsqldb.test.TestCollation.class);//
         suite.addTestSuite(org.hsqldb.test.TestDatabaseMetaData.class);
         suite.addTestSuite(org.hsqldb.test.TestDateTime.class);
+        suite.addTestSuite(org.hsqldb.test.TestINPredicateParameterizationAndCorrelation.class);//
+//        suite.addTestSuite(org.hsqldb.test.TestJDBCGeneratedColumns.class);//
         suite.addTestSuite(org.hsqldb.test.TestJDBCSavepoints.class);
-        suite.addTestSuite(org.hsqldb.test
-            .TestINPredicateParameterizationAndCorrelation.class);
-        suite.addTestSuite(org.hsqldb.test.TestSqlPersistent.class);
-        suite.addTestSuite(
-            org.hsqldb.test.TestLikePredicateOptimizations.class);
+        suite.addTestSuite(org.hsqldb.test.TestLikePredicateOptimizations.class);
+//        suite.addTestSuite(org.hsqldb.test.TestLobs.class);
+//        suite.addTestSuite(org.hsqldb.test.TestMerge.class);
+//        suite.addTestSuite(org.hsqldb.test.TestMultiInsert.class);
         suite.addTestSuite(org.hsqldb.test.TestSql.class);
-        suite.addTestSuite(org.hsqldb.test.TestGroupByHaving.class);
+        suite.addTestSuite(org.hsqldb.test.TestStoredProcedure.class);
         suite.addTestSuite(org.hsqldb.test.TestSubselect.class);
+        suite.addTestSuite(org.hsqldb.test.TestTextTable.class);
+        suite.addTestSuite(org.hsqldb.test.TestTextTables.class);
         suite.addTestSuite(org.hsqldb.test.TestTimestamp.class);
         suite.addTestSuite(org.hsqldb.test.TestViewAsterisks.class);
 
+        //
+        suite.addTestSuite(org.hsqldb.test.TestCascade.class);
+//        suite.addTestSuite(org.hsqldb.test.TestDataStructures.class);
+        suite.addTestSuite(org.hsqldb.test.TestGroupByHaving.class);
+        suite.addTestSuite(org.hsqldb.test.TestSqlPersistent.class);
         return suite;
     }
 }
